--[[
	Project....: BGRep
	File.......: BGRep.lua
	Description: Core file for BGRep
	Version....: 1.5
	Created....: December 23rd 2015 (Azhtyhx)
	Updated....: January 1st 2016 (Azhtyhx)
]]

-----------
-- Setup --
-----------

local addonName, BGRep = ...
BGRep = LibStub("AceAddon-3.0"):NewAddon("BGRep", "AceConsole-3.0")
BGRep.L = LibStub("AceLocale-3.0"):GetLocale(addonName)
local L = BGRep.L
local db
local ACR = LibStub("AceConfigRegistry-3.0")
local ACD = LibStub("AceConfigDialog-3.0")

BGRep.playerFaction = UnitFactionGroup("player")

BGRep.defaults = {
	profile = {
		modules = {
			BGRWindow = false,
			BGRMinimap = true,
		},
		mainWindow = {
			windowPosition = { "CENTER", nil, "CENTER", 0, 0, },
			windowWidth = 150,
			windowHeight = 50,
			fontSize = 14,
			windowColor = { 1.0, 0.5, 0, 0.5 },
			fontColor = { 1.0, 1.0, 1.0, 1.0},
		},
		minimapIcon = {
			minimapPos = 200,
		},
	},
	char = {
		wsgLastValue = 0,
		abLastValue = 0,
	},
}

-------------
-- Methods --
-------------

function BGRep:LoadOptions()
	BGRep.options = { 
		name = "BGRep",
		handler = BGRep,
		type = "group",
		args = {
			General = {
				name = L["General"],
				type = "group",
				order = 1,
				guiInline = false,
				args = {
					header = {
						type = "header",
						name = "General",
						order = 1,
					},
					window = {
						type = "toggle",
						name = L["Main Window"],
						desc = L["Show/Hide the BGRep Window"],
						order = 2,
						get = function() return db.modules.BGRWindow end,
						set = function(info, value)
							BGRep:ToggleModule("BGRWindow")
						end,
					},
					minimap = {
						type = "toggle",
						name = L["Minimap"],
						desc = L["Show/Hide the BGRep Minimap Icon"],
						order = 3,
						get = function() return db.modules.BGRMinimap end,
						set = function(info, value)
							BGRep:ToggleModule("BGRMinimap")
						end,
					},
				},
			},
			MainWindow = {
				name = L["Main Window"],
				type = "group",
				order = 2,
				guiInline = false,
				args = {
					headerone = {
						type = "header",
						name = "Size",
						order = 1,
					},
					windowWidth = {
						type = "input",
						name = L["Window Width"],
						desc = L["Choose the width of the BGRep Window"],
						order = 2,
						get = function() return tostring(db.mainWindow.windowWidth) end,
						set = function(info, value)
							if tonumber(value) ~= nil then
								db.mainWindow.windowWidth = value
								BGRWindow:Refresher(ww)
							end
						end,
					},
					windowHeight = {
						type = "input",
						name = L["Window Height"],
						desc = L["Choose the height of the BGRep Window"],
						order = 3,
						get = function() return tostring(db.mainWindow.windowHeight) end,
						set = function(info, value)
							if tonumber(value) ~= nil then
								db.mainWindow.windowHeight = value
								BGRWindow:Refresher(wh)
							end
						end,
					},
					fontSize = {
						type = "range",
						name = L["Font Size"],
						desc = L["Choose the font size of the BGRep Window"],
						min = 10,
						max = 34,
						step = 1,
						order = 4,
						get = function() return db.mainWindow.fontSize end,
						set = function(info, value)
							db.mainWindow.fontSize = value
							BGRWindow:Refresher(fs)
						end,
					},
					headertwo = {
						type = "header",
						name = "Color",
						order = 5,
					},
					backgroundColor = {
						type = "color",
						name = L["Background Color"],
						desc = L["Background color of the BGRep Window"],
						order = 7,
						cmdHidden = true,
						hasAlpha = true,
						get = function() return unpack(db.mainWindow.windowColor) end,
						set = function(info, wr, wg, wb, wa)
							db.mainWindow.windowColor = {wr, wg, wb, wa}
							BGRWindow:Refresher(bg)
						end,
					},
					fontColor = {
						type = "color",
						name = L["Font Color"],
						desc = L["Font color of the BGRep Window"],
						order = 8,
						cmdHidden = true,
						hasAlpha = true,
						get = function() return unpack(db.mainWindow.fontColor) end,
						set = function(info, wr, wg, wb, wa)
							db.mainWindow.fontColor = {wr, wg, wb, wa}
							BGRWindow:Refresher(fc)
						end,
					},
				},
			},
		}
	}
	
	return BGRep.options
end

function BGRep:GetDB(scope, extra)
	local scope = scope or "profile"
	db = self.db[scope]
	db.char = self.db.char
	return (extra) and db[extra] or db
end

function BGRep:ToggleModule(mName)
	if db.modules[mName] then
		db.modules[mName] = false
		BGRep:DisableModule(mName)
	else
		db.modules[mName] = true
		BGRep:EnableModule(mName)
	end
end

function BGRep:RegisterModule(module)
	local mName = module:GetName()
	module:SetEnabledState(db.modules[mName])
end

function BGRep:Open()
	if ACD.OpenFrames.BGRep then
		ACD:Close(addonName)
	else
		ACD:Open(addonName)
	end
end

function BGRep:ChatCommand(input)
	if not input or input:trim() == "" then
		self:Open()
	end
end

-----------------
-- Setup BGRep --
-----------------

function BGRep:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("BGRepDB", BGRep.defaults, true)
	db = self.db.profile
	LibStub("AceConfig-3.0"):RegisterOptionsTable("BGRep", self.LoadOptions)
	ACD:SetDefaultSize("BGRep", 600, 400)
	self:RegisterChatCommand(addonName, "ChatCommand")
end