--[[
	Project....: BGRep
	File.......: window.lua
	Description: Main window for BGRep
	Version....: 1.6
	Created....: December 23rd 2015 (Azhtyhx)
	Updated....: January 3rd 2016 (Azhtyhx)
]]

-----------
-- Setup --
-----------

BGRep = LibStub("AceAddon-3.0"):GetAddon("BGRep")
BGRWindow = BGRep:NewModule("BGRWindow", "AceConsole-3.0", "AceEvent-3.0")
local L = BGRep.L
local db
local BGRWindowFrame
local created = false

local wsgFlags = 0
local abTicks = 0
local wsgID = 0
local abID = 0
local wsgName
local abName
local testName = "Frostwolf Orcs"
local maxValue = 42000

-------------
-- Methods --
-------------

function BGRWindow:IDCheck(faction)
	if faction == "Horde" then
		wsgID = 889
		abID = 510
	elseif faction == "Alliance" then
		wsgID = 890
		abID = 509
	end
	
	wsgName = GetFactionInfoByID(wsgID)
	abName = GetFactionInfoByID(abID)
end

-- This is a bit of a mess. Need to find a solution one day.
function BGRWindow:UpdateWarsong()
	local name, description, standingID, barMin, barMax, barValue = GetFactionInfoByID(wsgID)
	db.char.wsgLastValue = barValue
	wsgFlags = math.floor((maxValue - db.char.wsgLastValue) / 100 + 0.5)
	
	BGRWindowFrame.Warsong:SetText(L["Warsong Gulch"] .. ": " .. wsgFlags)
end

function BGRWindow:UpdateArathi()
	local name, description, standingID, barMin, barMax, barValue = GetFactionInfoByID(abID)
	db.char.abLastValue = barValue
	abTicks = math.floor((maxValue - db.char.abLastValue) / 50 + 0.5)
	
	BGRWindowFrame.Arathi:SetText(L["Arathi Basin"] ..  ": " .. abTicks)
end

function BGRWindow:Update(message)
	if message == nil then
		BGRWindow:UpdateWarsong()
		BGRWindow:UpdateArathi()
	else
		local wsgTrue = string.find(message, wsgName)
		if wsgTrue then
			BGRWindow:UpdateWarsong()
		end
		
		local abTrue = string.find(message, abName)
		if abTrue then
			BGRWindow:UpdateArathi()
		end
	end
end

function BGRWindow:CreateAFrame()
	if created then return end
	BGRWindowFrame = CreateFrame("Frame", "BGRepFrame", UIParent)
	BGRWindowFrame:SetMovable(true)
	BGRWindowFrame:EnableMouse(true)
	BGRWindowFrame:RegisterForDrag("LeftButton")
	BGRWindowFrame:SetScript("OnMouseDown", BGRWindow.OnDragStart)
	BGRWindowFrame:SetScript("OnMouseUp", BGRWindow.OnDragStop)
	
	BGRWindowFrame:SetPoint(unpack(db.mainWindow.windowPosition))
	BGRWindowFrame:SetWidth(db.mainWindow.windowWidth)
	BGRWindowFrame:SetHeight(db.mainWindow.windowHeight)
	
	BGRWindowFrame.BG = BGRWindowFrame:CreateTexture("ARTWORK")
	BGRWindowFrame.BG:SetAllPoints()
	BGRWindowFrame.BG:SetTexture(unpack(db.mainWindow.windowColor))
	
	--Warsong Gulch Text
	BGRWindowFrame.Warsong = BGRWindowFrame:CreateFontString(nil, "ARTWORK")
	BGRWindowFrame.Warsong:SetPoint("CENTER", BGRWindowFrame.BG, "CENTER", 0, 10)
	BGRWindowFrame.Warsong:SetFont("Fonts\\FRIZQT__.TTF", db.mainWindow.fontSize)
	BGRWindowFrame.Warsong:SetTextColor(unpack(db.mainWindow.fontColor))
	BGRWindowFrame.Warsong:SetText("Warsong Gulch: " .. wsgFlags)
	
	--Arathi Basin Text
	BGRWindowFrame.Arathi = BGRWindowFrame:CreateFontString(nil, "ARTWORK")
	BGRWindowFrame.Arathi:SetPoint("CENTER", BGRWindowFrame.BG, "CENTER", 0, -10)
	BGRWindowFrame.Arathi:SetFont("Fonts\\FRIZQT__.TTF", db.mainWindow.fontSize)
	BGRWindowFrame.Arathi:SetTextColor(unpack(db.mainWindow.fontColor))
	BGRWindowFrame.Arathi:SetText("Arathi Basin: " .. abTicks)
	
	BGRWindowFrame:Hide()
	
	created = true
end

function BGRWindow:Refresher(refreshVar)
	if refreshVar == ww then
		BGRWindowFrame:SetWidth(db.mainWindow.windowWidth)
	end
	
	if refreshVar == wh then
		BGRWindowFrame:SetHeight(db.mainWindow.windowHeight)
	end
	
	if refreshVar == bg then
		BGRWindowFrame.BG:SetTexture(unpack(db.mainWindow.windowColor))
	end
		
	if refreshVar == fs then
		BGRWindowFrame.Warsong:SetFont("Fonts\\FRIZQT__.TTF", db.mainWindow.fontSize)
		BGRWindowFrame.Arathi:SetFont("Fonts\\FRIZQT__.TTF", db.mainWindow.fontSize)
	end
	
	if refreshVar == fc then
		BGRWindowFrame.Warsong:SetTextColor(unpack(db.mainWindow.fontColor))
		BGRWindowFrame.Arathi:SetTextColor(unpack(db.mainWindow.fontColor))
	end
end

-------------
-- Scripts --
-------------

function BGRWindow:OnDragStart(button)
	if button == "LeftButton" then
		self:StartMoving()
	end
end

function BGRWindow:OnDragStop(button)
	if button == "LeftButton" then
		self:StopMovingOrSizing()
		db.mainWindow.windowPosition = {BGRWindowFrame:GetPoint()}
	end
end

------------------
-- Setup Window --
------------------

function BGRWindow:OnInitialize()
	BGRep:RegisterModule(BGRWindow)
end

function BGRWindow:OnEnable()
	db = BGRep:GetDB()
	BGRWindow:IDCheck(BGRep.playerFaction)
	BGRWindow:CreateAFrame()
	BGRWindow:Update()
	BGRWindowFrame:Show()
	BGRWindow:RegisterEvent("CHAT_MSG_COMBAT_FACTION_CHANGE", BGRWindow.Update)
end

function BGRWindow:OnDisable()
	BGRWindowFrame:Hide()
	BGRWindow:UnregisterEvent("CHAT_MSG_COMBAT_FACTION_CHANGE", BGRWindow.Update)
end